@@ -39,9 +39,9 @@ static const R_CMethodDef crMethods[] = {
 
 
 extern void basis_reduction(int *noi,
-                   int *nos,
-                   int *bas,
-                   int *nob);
+                            int *nos,
+                            int *bas,
+                            int *nob);
 
 static R_NativePrimitiveArgType basis_paramtypes[] = {
   INTSXP, INTSXP, VECSXP, INTSXP
@@ -72,8 +72,6 @@ static const R_CMethodDef sfrMethods[] = {
 
 
 
-
-
 extern void dist(int *noi,        // number of items
                  int *data,       // data matrix as vector
                  int *nor,        // number of response patterns
@@ -92,6 +90,45 @@ static const R_CMethodDef dMethods[] = {
 
 
 
+extern void generate(int *noi,
+                     int *norp,
+                     int *data,
+                     int *t,
+                     int *rc,
+                     int *nos);
+
+static R_NativePrimitiveArgType generate_paramtypes[] = {
+  INTSXP, INTSXP, VECSXP, INTSXP, INTSXP, INTSXP
+};
+static const R_CMethodDef genMethods[] = {
+  {"generate", (DL_FUNC) &generate, 6, generate_paramtypes},
+  {0,0,0,0}
+};
+
+
+extern void generate_free_memory(void);
+
+// static R_NativePrimitiveArgType constr_free_memory_paramtypes[] = {};
+
+static const R_CMethodDef genfMethods[] = {
+  {"generate_free_memory", (DL_FUNC) &generate_free_memory, 4, NULL},
+  {0,0,0,0}
+};
+
+
+extern void generate_results(int *kstruct);
+
+static R_NativePrimitiveArgType generate_results_paramtypes[] = {VECSXP};
+
+static const R_CMethodDef genrMethods[] = {
+  {"generate_results", (DL_FUNC) &generate_results, 4, generate_results_paramtypes},
+  {0,0,0,0}
+};
+
+
+
+
+
 void R_init_kstMatrixCconstr(DllInfo *dll)
 {
   R_registerRoutines(dll, cMethods, NULL, NULL, NULL);
@@ -101,5 +138,8 @@ void R_init_kstMatrixCconstr(DllInfo *dll)
   R_registerRoutines(dll, bMethods, NULL, NULL, NULL);
   R_registerRoutines(dll, brMethods, NULL, NULL, NULL);
   R_registerRoutines(dll, sfrMethods, NULL, NULL, NULL);
+  R_registerRoutines(dll, genMethods, NULL, NULL, NULL);
+  R_registerRoutines(dll, genfMethods, NULL, NULL, NULL);
+  R_registerRoutines(dll, genrMethods, NULL, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
 }
